
##########################################################################
#####################Group Theoretic Functions############################
##########################################################################

#Computes the minimal image of a set of subsets under the action of S8 (faster than computing orbit)
function minimalImage(Q)
	G = symmetric_group(8)
    m=GAP.Globals.MinimalImage(GAP.julia_to_gap(G),GapObj(Array([GapObj(Array(q)) for q in Q])),GAP.Globals.OnSetsSets)
    K=[GAP.gap_to_julia(k) for k in GAP.gap_to_julia(m)]
    return(Vector{Vector{Int64}}(K))
end

#Computes the stabilizer of the matroidal part of a quatroid
function MatroidStabilizer(Q)
    G = symmetric_group(8)
    X = [1,2,3,4,5,6,7,8]
    GS = gset(G,on_sets_sets,X)
    H=(stabilizer(GS.group,Triples(Q),on_sets_sets))[1]
    HS = gset(H,on_sets_sets,X)
    return(HS)
end

#Computes the orbit of Q under the stabilizer HS of the matroidal part. Return a canonical rep.
function MatroidStabilizedOrbit(Q,HS)
	Q=sort([sort(q) for q in Q])
    if length(Q)==0
        return Q
    end
	#Find and sort the orbit
    O=sort([sort(collect(keys(a.dict))) for a in (orbit(HS,Set(Q))).seeds])
	#Pull the first element
    O=O[1]
    return(O)
end

#Computes orbit of a set of sets under a group action
function orb(G,A)
    A = sort([sort(a) for a in A])
    O = sort(collect(orbit(G,on_sets_sets,A)))
    return(O)
end

#Computes orbit of set of subsets of [1..8] under S_8
function orb(S)
	G = symmetric_group(8)
	return(orb(G,S))
end

#Computes the size of an orbit of a quatroid
function orbsize(CQ)
    G = symmetric_group(8)
	Q = sort([sort(q) for q in CQ])
    gQ = GAP.julia_to_gap(Q,recursive=true)
    gG = GAP.julia_to_gap(G)
    n=GAP.Globals.OrbitLength(gG,gQ,GAP.Globals.OnSetsSets)
end
