

##########################################################################
#####################Orderings and parsing    ############################
##########################################################################

# The reverse lexicographic ordering
function revLex(f1::AbstractVector{Int64}, f2::AbstractVector{Int64})::Bool
	if maximum( f1 ) < maximum( f2 )
    	return true
    elseif maximum( f1 ) > maximum( f2 )
    	return false
	else
    	if length( f1 ) > 1
      		return revLex( view(f1,1:(length( f1 )-1)), view(f2,1:(length( f2 )-1)))
      	else
      		return false
      	end
    end
end

# A function for converting 0/* strings from the matroid database into sets of nonbases
function string_to_nonbases(str::String,r::Int,n::Int)
    C = sort(collect(combinations(1:n,r)),lt=revLex)
    Nonbases=[]
    for i in 1:length(C)
        if str[i]=="0"[1]
            push!(Nonbases,C[i])
        end
    end
    return Nonbases
end


#These help sort the quatroids into a better order (internally and externally)
function OuterQuatroidLT(Q1,Q2)
    S1 = QuatroidSignature(Q1)
    S2 = QuatroidSignature(Q2)
    if S1[1]<S2[1] #First order by matroid number
        true
    elseif S1[1]>S2[1]
        false
    else
        if S1[3]<S2[3] #Tie break matroid numbers by # of conics
            true
		elseif S1[3]>S2[3]
			false
        else
			if Sextuples(Q1)<Sextuples(Q2) #Tie break quatroids Lex on the conic part
				true
			else
				false
			end
        end
    end
end

#sort the I/J parts of quatroids by length (i.e. I then J)
function InnerQuatroidLT(S1,S2)
    if length(S1)<length(S2)
        true
    elseif S1<S2
		true
    else
        false
    end
end
